==> aroundme_0_3_3.tar: aroundme_0_3_3/www/aroundme_0_3_3/template/am_default/node_menu.inc.tpl.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of aroundme
// 
// Copyright (C) 2003, 2004 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
// 
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
// 
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
// 02111-1307, USA.
// -----------------------------------------------------------------------

?>


<table border="0" cellspacing="0" cellpadding="4" width="100%">
	<tr>
		<td class="txt_title">
			<?php echo $lang['section_menu'];?><br />
			<hr />
		</td>
	</tr>
	<tr>
		<td valign="top" class="txt_sub_menu_on">
			<?php
			if ($page_name_short == 'node_admin' && isset($groups)) {
			    echo $lang['menu_group_list'] . "<br />";
			}
			else {
				echo "<a href='node_admin.php?list_groups=1' class=\"txt_sub_menu\">" . $lang['menu_group_list'] . "</a><br />";
			}

			if ($page_name_short == 'node_admin' && isset($users)) {
			    echo $lang['menu_user_list'] . "<br />";
			}
			else {
				echo "<a href='node_admin.php?list_users=1' class=\"txt_sub_menu\">" . $lang['menu_user_list'] . "</a><br />";
			}

			if ($page_name_short == 'node_newsletter') {
			    echo $lang['menu_newsletter'] . "<br />";
			}
			else {
				echo "<a href='node_newsletter.php' class=\"txt_sub_menu\">" . $lang['menu_newsletter'] . "</a><br />";
			}

			if ($page_name_short == 'node_acs') {
			    echo $lang['menu_acs'] . "<br />";
			}
			else {
				echo "<a href='node_acs.php' class=\"txt_sub_menu\">" . $lang['menu_acs'] . "</a><br />";
			}

			if ($page_name_short == 'node_abuse_reports') {
			    echo $lang['menu_abuse_reports'] . "<br />";
			}
			else {
				echo "<a href='node_abuse_reports.php' class=\"txt_sub_menu\">" . $lang['menu_abuse_reports'] . "</a><br />";
			}
			?>

		</td>
	</tr>
</table>

==> aroundme-0_4_0.tar: aroundme_0_4_0/www/aroundme_0_4_0/template/am_default/node_menu.inc.tpl.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of aroundme
// 
// Copyright (C) 2003, 2005 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
// 
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
// 
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
// 02111-1307, USA.
// -----------------------------------------------------------------------

?>


<table border="0" cellspacing="0" cellpadding="4" width="100%">
	<tr>
		<td class="txt_title">
			<?php echo $lang['section_menu'];?><br />
			<hr />
		</td>
	</tr>
	<tr>
		<td valign="top" class="txt_sub_menu_on">
			<?php
			if ($page_name_short == 'node_group') {
			    echo $lang['menu_group_list'] . "<br />";
			}
			else {
				echo "<a href='node_group.php' class=\"txt_sub_menu\">" . $lang['menu_group_list'] . "</a><br />";
			}

			if ($page_name_short == 'node_user') {
			    echo $lang['menu_user_list'] . "<br />";
			}
			else {
				echo "<a href='node_user.php' class=\"txt_sub_menu\">" . $lang['menu_user_list'] . "</a><br />";
			}

			if ($page_name_short == 'node_newsletter') {
			    echo $lang['menu_newsletter'] . "<br />";
			}
			else {
				echo "<a href='node_newsletter.php' class=\"txt_sub_menu\">" . $lang['menu_newsletter'] . "</a><br />";
			}

			if ($page_name_short == 'node_acs') {
			    echo $lang['menu_acs'] . "<br />";
			}
			else {
				echo "<a href='node_acs.php' class=\"txt_sub_menu\">" . $lang['menu_acs'] . "</a><br />";
			}

			if ($page_name_short == 'node_cms') {
			    echo $lang['menu_cms'] . "<br />";
			}
			else {
				echo "<a href='node_cms.php' class=\"txt_sub_menu\">" . $lang['menu_cms'] . "</a><br />";
			}

			if ($page_name_short == 'node_abuse_reports') {
			    echo $lang['menu_abuse_reports'] . "<br />";
			}
			else {
				echo "<a href='node_abuse_reports.php' class=\"txt_sub_menu\">" . $lang['menu_abuse_reports'] . "</a><br />";
			}
			?>

		</td>
	</tr>
</table>
